@@ -177,7 +177,6 @@ Jest \$hostCntGood hostów które zostaly zabezpieczone, na całkowita liczbę:
     <td align="center"> Ostatnia próba </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Hosty bez wykonanej kopii bezpieczeństwa")}
 <p>
 Jest \$hostCntNone hostów bez kopii bezpieczeństwa.
@@ -374,7 +373,6 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Podsumowanie kolejki";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Podsumowanie kolejki kopii bezpieczeństwa")}
-<br><br>
 \${h2("Podsumowanie kolejki uzytkownika")}
 <p>
 Następujący użytkonicy są w kolejce:
@@ -385,7 +383,6 @@ Następujący użytkonicy są w kolejce:
     <td> Użytkownik </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Podsumowanie kolejki w tle")}
 <p>
@@ -397,7 +394,6 @@ Następujące kolejki będące w tle czekają na wykonanie :
     <td> uzytkownik </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Podsumowanie kolejki poleceń")}
 <p>
 Następujące kolejki poleceń czekają na wykonanie :
@@ -695,9 +691,7 @@ Kliknij na numer kopii aby przeglądać i przywracać wybrane pliki/katalogi.
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Podsumowanie błędów Xfer")}
-<br><br>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
@@ -709,7 +703,6 @@ Kliknij na numer kopii aby przeglądać i przywracać wybrane pliki/katalogi.
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("Ilość/wielkość użytych ponownie plików")}
 <p>
@@ -736,7 +729,6 @@ Puste pliki i błędy SMB nie są liczone.
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Podsumowanie Kompresji")}
 <p>
@@ -759,7 +751,6 @@ Wydajność kompresji dla plików będących w puli oraz tych świeżo skompreso
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Podsumowanie Archiwizacji hosta \$host";
@@ -897,7 +888,7 @@ Przedstawienie każdej unikalnej wersji każdego pliku we wszystkich kopiach:
 <li> Kliknij na wersje pliku (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) aby śćiagnać ten plik,
 <li> Pliki z tą samą zawartością pomiędzy różnymi kopiami mają ten sam
-     numer wersji,
+     numer wersji (PleaseTranslateThis: except between v3 and v4 backups),
 <li> Pliki lub adresy ,które nie są dostępne w określonej kopii
      nie są zaznaczone.
 <li> Pliki pokazane z tą samą wersją mogą mieć inny atrybut.
